/***************************************************************************//**
 *   @file   AD5172.h
 *   @brief  Header file of AD5172 Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 610
*******************************************************************************/
#ifndef __AD5172_H__
#define __AD5172_H__

/*****************************************************************************/
/* AD5172                                                                    */
/*****************************************************************************/
#define AD5172_DEVICE_ADDR   0x2F

/* Instruction bits*/
#define AD5172_A0      (1 << 7) // RDAC subaddress select bit.
#define AD5172_SD      (1 << 6) // Shutdown.
#define AD5172_T       (1 << 5) // OTP programming bit.
#define AD5172_OW      (1 << 3) // Overwrites the fuse setting and programs the
                                // digital potentiometer to a different setting.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/

/* Initializes the communication with the device. */
unsigned char AD5172_Init(void);

/* Sets or clears the Shutdown bit. */
void AD5172_Shutdown(unsigned char channel, unsigned char flag);

/* The channel is being one-time programmed(OTP). */
void AD5172_Otp(unsigned char channel, unsigned char data);

/* Sends data to one of the 2 channels available. */
void AD5172_WriteRDAC(unsigned char channel, unsigned char data);

/* Reads a byte form the selected channel. */
unsigned char AD5172_ReadRDAC(unsigned char channel);

#endif	// AD5172_H_
